@@ -9,7 +9,7 @@ use Carp qw( croak carp );
 use File::ShareDir ();
 
 # ABSTRACT: Tiny C Compiler for FFI
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 
 sub _dlext
@@ -321,7 +321,7 @@ FFI::TinyCC - Tiny C Compiler for FFI
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 SYNOPSIS
 
@@ -339,7 +339,7 @@ version 0.16
  });
  
  my $address = $tcc->get_symbol('find_square');
- function [$address => 'find_square'] => [int] => int;
+ attach [$address => 'find_square'] => [int] => int;
  
  print find_square(4), "\n"; # prints 16
 
@@ -585,7 +585,7 @@ Or better yet, use L<FFI::Platypus> instead.
  
  my $address = $tcc->get_symbol('calculate_square');
  
- function [$address => 'square'] => [int] => int;
+ attach [$address => 'square'] => [int] => int;
  
  print square($value), "\n";
 
@@ -637,7 +637,7 @@ Graham Ollis <plicease@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Graham Ollis.
+This software is copyright (c) 2015 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
